A library that is used to calculate the distance between 2 coordinates

**Installation**

`pip install geodistance`

**Get Started**
Calculating distance between 2 coordinates

`from geodistance import Geodistance`

`length = Geodistance().distance(42.546245, 1.601554, 23.424076, 53.847818)`

`print(length)`